@@ -8,12 +8,9 @@ Catalyst::Plugin::CustomErrorMessage - Catalyst plugin to have more "cute" error
 
 	use Catalyst qw( CustomErrorMessage );
 	
-	# optional (values in this example are the defaults)
-	__PACKAGE__->config->{'custom-error-messsage'}->{'uri-for-not-found'} = '/';
-	__PACKAGE__->config->{'custom-error-messsage'}->{'error-template'}    = 'error.tt2';
-	__PACKAGE__->config->{'custom-error-messsage'}->{'content-type'}      = 'text/html; charset=utf-8';
-	__PACKAGE__->config->{'custom-error-messsage'}->{'view-name'}         = 'TT';
-	__PACKAGE__->config->{'custom-error-messsage'}->{'response-status'}   = 500;
+	# optional
+	__PACKAGE__->config->{'custome-error-messsage'}->{'uri-for-not-found'} = '/not_found_error';
+	__PACKAGE__->config->{'custome-error-messsage'}->{'error-template'}    = 'error.tt2';
 
 =head1 DESCRIPTION
 
@@ -42,7 +39,7 @@ use NEXT;
 use strict;
 use warnings;
 
-our $VERSION = "0.03_03";
+our $VERSION = "0.01";
 
 
 =head1 FUNCTIONS
@@ -53,7 +50,7 @@ In debug mode this function is skipped and user sees the original Catalyst error
 
 In "production" (non debug) mode it will return page with template set in
 
-	$c->config->{'custom-error-messsage'}->{'error-template'}
+	$c->config->{'custome-error-messsage'}->{'error-template'}
 	||
 	'error.tt2'
 
@@ -62,27 +59,23 @@ $c->stash->{'finalize_error'} will be set to contain the error message.
 For non existing resources (like misspelled url-s) if will do http redirect to
 
 	$c->uri_for(
-		$c->config->{'custom-error-messsage'}->{'uri-for-not-found'}
+		$c->config->{'custome-error-messsage'}->{'uri-for-not-found'}
 		||
 		'/'
 	)
 
 $c->flash->{'finalize_error'} will be set to contain the error message.
 
-To set different view name configure:
-
-	$c->config->{'custom-error-messsage'}->{'view-name'} = 'Mason';
-
-Content-type and response status can be configured via: 
-
-	$c->config->{'custom-error-messsage'}->{'content-type'}    = 'text/plain; charset=utf-8';
-	$c->config->{'custom-error-messsage'}->{'response-status'} = 500;
+This works if you are using Template Toolkit and the view is named "TT".
+The "tutorial" way. If you want it the different way just copy this module, place it
+to the lib/Catalyst/Plugin folder and edit out for your needs. If we can improve
+this example by some config switch, so that it will be more universal, then please let
+me know and i'll put it there. 
 
 =cut
 
 sub finalize_error {
 	my $c = shift;
-	my $config = $c->config->{'custome-error-messsage'} || $c->config->{'custom-error-messsage'};
 	
 	# in debug mode return the original "page" 
 	if ( $c->debug ) {
@@ -91,15 +84,15 @@ sub finalize_error {
 	}
 	
 	# create error string out of error array
-	my $error = join '<br/> ', map { encode_entities($_) } @{ $c->error };
+	my $error = join '', map { encode_entities($_).'<br/> ' } @{ $c->error };
 	$error ||= 'No output';
 
 	# for wrong url that has no action associated do redirect
 	if (not defined $c->action) {
-		$c->flash->{'finalize_error'} = $error;
+		$c->flash->{'finalize_error'} = $error."<br/>";
 		$c->_save_flash(); # hack but must be called otherwise the flash data will be lost
 		$c->response->redirect($c->uri_for(
-			$config->{'uri-for-not-found'}
+			$c->config->{'custome-error-messsage'}->{'uri-for-not-found'}
 			||
 			'/'
 		));
@@ -110,27 +103,13 @@ sub finalize_error {
 	# render the template
 	my $action_name = $c->action->reverse;
 	$c->stash->{'finalize_error'} = $action_name.': '.$error;
-	$c->response->content_type(
-		$config->{'content-type'}
+	$c->response->content_type('text/html; charset=utf-8');
+	$c->response->body($c->view('TT')->render($c,
+		$c->config->{'custome-error-messsage'}->{'error-template'}
 		||
-		'text/html; charset=utf-8'
-	);
-	my $view_name = $config->{'view-name'} || 'TT';
-	eval {
-		$c->response->body($c->view($view_name)->render($c,
-			$config->{'error-template'}
-			||
-			'error.tt2'
-		));
-	};
-	if ($@) {
-		$c->log->error($@);
-		$c->NEXT::finalize_error;
-	}
-	
-	my $response_status = $config->{'response-status'};
-	$response_status = 500 if not defined $response_status;
-	$c->response->status($response_status);
+		'error.tt2'
+	));
+	$c->response->status(500);
 }
 
 1;
@@ -139,6 +118,8 @@ sub finalize_error {
 
 Jozef Kutej - E<lt>jozef@kutej.netE<gt>
 
+Authorization and Accounting contributed by Rubio Vaughan E<lt>rubio@passim.netE<gt>
+
 =head1 TODO
 
 More universal? Looking forward for your suggestions.
